#
#  Copyright 1996-2014 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::devs - Looking for all block and characater special devices locations
#
package Security::devs;

use Security::util::print;
use Security::util::read_config;
use Security::find;
use Exporter;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( init print );

our (%devs);

sub init {
	print ( STDERR  "In Security::devs::init()\n") if ( $main::opts{'d'} );

	&read_config('ignoredevdir');
	&Security::find::add_wanted (\&devs_wanted);
}

# Implement the find subroutine to look for the block and character
# special devices not under ignoredevdir
sub devs_wanted {
	my ($file) = @_;

	if  ( ! -l $file && ( -b $file || -c $file )) {
		my ($res) = 1;
		foreach my $i ( @{$main::config{'ignoredevdir'}} ) {
			$res = 0 if ( $File::Find::name =~ /^$i/ );
		}
		$devs{$File::Find::name} = 1 if ($res);
	}
}

sub print {
	print ( STDERR  "In Security::devs::print()\n") if ( $main::opts{'d'} );

	&print_data ("\n\nchecking for block & character special devices not in /dev:\n", %devs);
}

1;

__END__

=head1 NAME

Security::devs - Find block and character special files.

=head1 SYNOPSIS

Security::devs::devs_wanted

=head1 DESCRIPTION

Looks for all the block and character special devices that are not listed
under any directory defined in C<ignoredevdir>.

=head1 API

This module implements the default API:

=over 4

=item C<init()>

Calls C<read_config (ignoredevdir)> to get the list of directories where
block and character special devices are permitted.

Calls C<Security::find::add_wanted> to register the C<dev_wanted> sub routine.

=item C<print()>

Calls C<print_data ()> to print out the list of block and character special
devices that we found not under C<ignoredevdir>.

=back 

=head1 CONFIGURATION OPTIONS

The script will call C<read_config> on the following config file options:

=over 4

=item C<ignoredevdir>

The list of directories where block and character special devices should
be found.

=back

=head1 HISTORY

This idea of tracking where block and character special devices was suggested
in the C<HP-UX System Security Manual>

=head1 SEE ALSO

L<Security::find>

L<perl>

=cut

