#!/usr/bin/env perl
#
#  Copyright 1996-2014 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  02.t - Test that DB_File will create a non zero database.
#		Test the verify checksum code.
#

use Test;
use strict;
use warnings "all";

use Security::util::SHA1;
use Security::db;

our $checksum_file = 'tmp.db';
our ($format, %opts);
my @files = (
	$0,
	$checksum_file,
);
$opts{'M'} = '-';
#$opts{'d'} = 1;

plan tests => scalar @files + 1;

sub print_data {}

&Security::util::SHA1::init();
&Security::db::init();

# Fill in the DB with our initial checksums.
foreach my $file ( @files ) {
	&Security::db::verify($file);
}
&Security::db::print();
&Security::db::destroy();

# Now reopen the db and check the results.
&Security::db::init();
foreach my $file ( @files ) {
	&Security::db::verify($file);
	if ( exists $Security::db::badchecksums{$file} && $file ne $checksum_file ) {
		ok(0, 1, "Bad checksum for file $file");
	} else {
		ok(1, 1, "Checksum match for file $file");
	}
}
&Security::db::destroy();

ok(((-s $checksum_file)>0), 1, "DB_File database is size zero");

unlink ($checksum_file);
