#!/usr/bin/env perl
#
#  Copyright 1996-2014 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  13.t - rootlogin module testing
#

use Test;
use strict;
use warnings "all";

use Security::rootlogin;

plan tests => 11;

our (%opts, %config);
#$opts{'d'} = 1;

# Setup defaults
@{$config{'ignorerootports'}} = (
	'console',
	'tty'
);

# first test the check_securettys() function
our $securefile = './t/rootlogin';
my $FP;
my $secure = "
console
tty
zero
bad
";

open ($FP, ">$securefile") || die "Could not write out test t/rootlogin file\n";
print $FP $secure;
close $FP;

&Security::rootlogin::check_securettys();

# Make sure we found all the bad root accounts
ok ( scalar keys %Security::rootlogin::ttys, 1, "Could not find the correct number of bad root ports");
ok ( $Security::rootlogin::ttys{'tty'}, undef, "Found a bad root port (that we should not have found)");
ok ( $Security::rootlogin::ttys{'zero'}, 1, "Could not find a bad root port");

# Reset everything to run the check_defaultlogin() test
map { delete $Security::rootlogin::ttys{$_}; } keys %Security::rootlogin::ttys;

$secure = "
# If CONSOLE is set, root can only login on that device.
# Comment this line out to allow remote login by root.
#
CONSOLE=/dev/console
";
our $loginfile = './t/rootlogin';
open ($FP, ">$loginfile") || die "Could not write out test t/rootlogin file\n";
print $FP $secure;
close $FP;

&Security::rootlogin::check_defaultlogin();

ok ( $Security::rootlogin::rootlogin, !0, "Could not determine that root was limited to console");

# Reset everything
$Security::rootlogin::rootlogin = -1;
$secure = "
# If CONSOLE is set, root can only login on that device.
# Comment this line out to allow remote login by root.
#
#CONSOLE=/dev/console
";
open ($FP, ">$loginfile") || die "Could not write out test t/rootlogin file\n";
print $FP $secure;
close $FP;

&Security::rootlogin::check_defaultlogin();

ok ( $Security::rootlogin::rootlogin, 0, "Could not determine that root was not limited to console");

# Now reset to run the check_ttys() tests
$secure = "
console \"/System/Library/CoreServices/loginwindow.app/Contents/MacOS/loginwindow\" vt100 on secure onoption=\"/usr/libexec/getty std.9600\"
zero		\"/usr/libexec/getty std.9600\"	unknown	on secure
tty.serial     \"/usr/libexec/getty serial.57600\"        vt100   off secure
tty[00-07]	\"/usr/libexec/getty std.9600\"	unknown	off secure
ttyp[0x0-0xf]	none			network slot=36
";
open ($FP, ">$securefile") || die "Could not write out test t/rootlogin file\n";
print $FP $secure;
close $FP;

&Security::rootlogin::check_ttys();

ok ( scalar keys %Security::rootlogin::ttys, 1, "Could not find the correct number of bad root ports");
ok ( $Security::rootlogin::ttys{'console'}, undef, "Found a bad root port (that we should not have found)");
ok ( $Security::rootlogin::ttys{'zero'}, 1, "Could not find a bad root port");

# Now restart to run the check_access() tests
map { delete $Security::rootlogin::ttys{$_}; } keys %Security::rootlogin::ttys;
our $accessfile = './t/rootlogin';
$secure = '+:root:console zero
';

open ($FP, ">$accessfile") || die "Could not write out test t/rootlogin file\n";
print $FP $secure;
close $FP;

&Security::rootlogin::check_access();

ok ( scalar keys %Security::rootlogin::ttys, 1, "Could not find the correct number of bad root ports");
ok ( $Security::rootlogin::ttys{'console'}, undef, "Found a bad root port (that we should not have found)");
ok ( $Security::rootlogin::ttys{'zero'}, 1, "Could not find a bad root port");

unlink ('./t/rootlogin');

exit 0;
